@@ -35,10 +35,10 @@ function(object, XX=NULL, BTE=c(0,1,1), R=1, MAP=TRUE, pred.n=TRUE, krige=TRUE,
          zcov=FALSE, Ds2x=FALSE, improv=FALSE, sens.p=NULL, trace=FALSE, verb=0, ...)
 {
   ## (quitely) double-check that tgp is clean before-hand
-  tgp.cleanup(message="NOTICE", verb=verb, rmfile=TRUE);
+  tgp.cleanup(message="NOTICE", verb=verb, rmfiles=TRUE);
   
   ## what to do if fatally interrupted?
-  on.exit(tgp.cleanup(verb=verb, rmfile=TRUE))
+  on.exit(tgp.cleanup(verb=verb, rmfiles=TRUE))
 
   if(object$params$corr == "mrexpsep" && !is.null(sens.p))
     stop("Sorry, sensitivity analysis is not yet available for corr=\"mrexpsep\"")
