@@ -31,8 +31,6 @@
 #include "lik_post.h"
 #include "all_draws.h"
 #include "rhelp.h"
-#include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 
 /* constants used below */
@@ -221,7 +219,7 @@ double tau2, itemp;
   /* now for lambda */
   lambda = ZZ + b0Tib0 - BVBiB;
   
-  /* myprintf(stderr, 
+  /* myprintf(mystderr, 
      "noK: n=%d, itemp=%g, ZZ=%g, tau2=%g, b0Tib0/tau2=%g, BVBiB=%g, lambda=%g\n", 
      n, itemp, ZZ, tau2, b0Tib0, BVBiB, lambda); */
 
@@ -341,7 +339,7 @@ double tau2, itemp;
   /* now for lambda */
   lambda = ZKiZ + b0Tib0/tau2 - BVBiB;
 
-  /* myprintf(stderr, "n=%d, itemp=%g, ZKiZ=%g, tau2=%g, b0Tib0/tau2=%g, BVBiB=%g, lambda=%g\n", 
+  /* myprintf(mystderr, "n=%d, itemp=%g, ZKiZ=%g, tau2=%g, b0Tib0/tau2=%g, BVBiB=%g, lambda=%g\n", 
     n, itemp, ZKiZ, tau2, b0Tib0/tau2, BVBiB, lambda); */
 
   /* this is here because when itemp=0 lambda should be 0, but
@@ -424,7 +422,7 @@ void *state;
   /* s2 = 1/gamrnd(alpha, 1/g, 1) */
   /* return 1.0 / (1.0/g * rgamma(alpha)); */
   inv_gamma_mult_gelman(&x, alpha, g, 1, state);
-  /* myprintf(stderr, "alpha = %g, beta = %g  =>  x = %g\n", alpha, g, x); */
+  /* myprintf(mystderr, "alpha = %g, beta = %g  =>  x = %g\n", alpha, g, x); */
   return x;
 }
 
@@ -1057,7 +1055,7 @@ void *state;
   pdlast = post_margin(n,col,lambda,Vb,log_det_K,a0-m,g0,itemp);
   pdlast += log_d_prior_pdf(dlast, d_alpha, d_beta);
   
-  /* if(lin && pd > pdlast) myprintf(stderr, "pd=%g, pdlast=%g, qRatio=%g\n",
+  /* if(lin && pd > pdlast) myprintf(mystderr, "pd=%g, pdlast=%g, qRatio=%g\n",
      pd, pdlast, qRatio); */
 
   /* compute acceptance prob */
@@ -1322,9 +1320,9 @@ void *state;
   
   /* accept or reject */
   alpha = exp(pnug - pnuglast)*(q_bak/q_fwd);
-  /* myprintf(stderr, "nug_last=%g -> nug=%g : alpha=%g\n", nuglast, nug, alpha); */
-  if(runi(state) > alpha) { /* myprintf(stderr, "  -- rejected\n");*/ return nuglast; }
-  else { /*myprintf(stderr, "  -- accepted\n");*/ return nug; }
+  /* myprintf(mystderr, "nug_last=%g -> nug=%g : alpha=%g\n", nuglast, nug, alpha); */
+  if(runi(state) > alpha) { /* myprintf(mystderr, "  -- rejected\n");*/ return nuglast; }
+  else { /*myprintf(mystderr, "  -- accepted\n");*/ return nug; }
 }
 
 
@@ -1405,7 +1403,7 @@ void *state;
   
   if(runi(state) > alpha){
     /* printf("nugs %g %g\n",nug, nugfine); */
-    /*printVector(newnugs, 2, stdout, HUMAN); */
+    /*printVector(newnugs, 2, mystdout, HUMAN); */
     newnugs[0] = nug;
     newnugs[1] = nugfine;
   }
