@@ -39,7 +39,6 @@ extern "C"
 #include "sim.h"
 #include <math.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 #include <string.h>
 #include <string>
@@ -748,8 +747,8 @@ void Sim_Prior::read_double(double *dparams)
 
   /* read the starting value(s) for the range parameter(s) */
   for(unsigned int i=0; i<dim; i++) d[i] = dparams[1];
-  /*myprintf(stdout, "starting d=");
-    printVector(d, dim, stdout, HUMAN); */
+  /*myprintf(mystdout, "starting d=");
+    printVector(d, dim, mystdout, HUMAN); */
 
   /* reset the d parameter to after nugget and gamlin params */
   dparams += 13;
@@ -765,7 +764,7 @@ void Sim_Prior::read_double(double *dparams)
 
   /* d hierarchical lambda prior parameters */
   if((int) dparams[0] == -1)
-    { fix_d = true; /*myprintf(stdout, "fixing d prior\n");*/ }
+    { fix_d = true; /*myprintf(mystdout, "fixing d prior\n");*/ }
   else {
     fix_d = false;
     get_mix_prior_params_double(d_alpha_lambda, d_beta_lambda, dparams, "d lambda");
@@ -791,6 +790,7 @@ void Sim_Prior::read_double(double *dparams)
  /* Choleski decompose */
   int info = linalg_dpotrf(dim, dp_cov_chol);
   assert(info == 0); 
+  info = 0; /* for NDEBUG */
 }
 
 
@@ -812,8 +812,8 @@ void Sim_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   d[0] = atof(strtok(line, " \t\n#"));
   for(unsigned int i=1; i<dim; i++) d[i] = d[0];
-  myprintf(stdout, "starting d=", d);
-  printVector(d, dim, stdout, HUMAN);
+  myprintf(mystdout, "starting d=", d);
+  printVector(d, dim, mystdout, HUMAN);
 
   /* read d and nug-hierarchical parameters (mix of gammas) */
   double alpha[2], beta[2];
@@ -828,7 +828,7 @@ void Sim_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   strcpy(line_copy, line);
   if(!strcmp("fixed", strtok(line_copy, " \t\n#")))
-    { fix_d = true; myprintf(stdout, "fixing d prior\n"); }
+    { fix_d = true; myprintf(mystdout, "fixing d prior\n"); }
   else {
     fix_d = false;
     get_mix_prior_params(d_alpha_lambda, d_beta_lambda, line, "d lambda");  
@@ -1079,7 +1079,7 @@ void Sim_Prior::SetBasePrior(Base_Prior *base_prior)
 
 void Sim_Prior::Print(FILE *outfile)
 {
-  myprintf(stdout, "corr prior: separable power\n");
+  myprintf(mystdout, "corr prior: separable power\n");
 
   /* print nugget stuff first */
   PrintNug(outfile);
@@ -1101,7 +1101,7 @@ void Sim_Prior::Print(FILE *outfile)
   /* range gamma hyperprior */
   if(fix_d) myprintf(outfile, "d prior fixed\n");
   else {
-    myprintf(stdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+    myprintf(mystdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
 	     d_beta_lambda[1]);
   }
